VIAA lump
=========

.. image:: https://img.shields.io/github/license/viaacode/lump.svg
   :target: https://github.com/viaacode/lump/blob/master/LICENSE

.. image:: https://img.shields.io/github/issues/viaacode/lump.svg?logo=github
   :target: https://github.com/viaacode/lump/issues

.. image:: https://readthedocs.org/projects/lump/badge/?version=stable
   :target: https://lump.readthedocs.io/
   :alt: Documentation Status

A python library of disparate classes, functions and decorators frequently useful for other projects at VIAA.

